# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, allow_list_ids=None, auto_renew=None, backup_point_name=None, capacity=None, charge_type=None, configure_nodes=None, create_backup=None, create_time=None, data_layout=None, deletion_protection=None, engine_version=None, expired_time=None, id=None, instance_class=None, instance_id=None, instance_name=None, instance_shards=None, maintenance_time=None, max_connections=None, multi_az=None, no_auth_mode=None, node_ids=None, node_number=None, parameter_group_id=None, password=None, port=None, private_address=None, project_name=None, purchase_months=None, reserve_additional_bandwidth=None, service_type=None, shard_capacity=None, shard_number=None, sharded_cluster=None, status=None, subnet_id=None, tags=None, vi_pv6=None, vip=None, visit_addrs=None, vpc_auth_mode=None, vpc_id=None, zone_ids=None):
        if allow_list_ids and not isinstance(allow_list_ids, list):
            raise TypeError("Expected argument 'allow_list_ids' to be a list")
        pulumi.set(__self__, "allow_list_ids", allow_list_ids)
        if auto_renew and not isinstance(auto_renew, bool):
            raise TypeError("Expected argument 'auto_renew' to be a bool")
        pulumi.set(__self__, "auto_renew", auto_renew)
        if backup_point_name and not isinstance(backup_point_name, str):
            raise TypeError("Expected argument 'backup_point_name' to be a str")
        pulumi.set(__self__, "backup_point_name", backup_point_name)
        if capacity and not isinstance(capacity, dict):
            raise TypeError("Expected argument 'capacity' to be a dict")
        pulumi.set(__self__, "capacity", capacity)
        if charge_type and not isinstance(charge_type, str):
            raise TypeError("Expected argument 'charge_type' to be a str")
        pulumi.set(__self__, "charge_type", charge_type)
        if configure_nodes and not isinstance(configure_nodes, list):
            raise TypeError("Expected argument 'configure_nodes' to be a list")
        pulumi.set(__self__, "configure_nodes", configure_nodes)
        if create_backup and not isinstance(create_backup, bool):
            raise TypeError("Expected argument 'create_backup' to be a bool")
        pulumi.set(__self__, "create_backup", create_backup)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if data_layout and not isinstance(data_layout, str):
            raise TypeError("Expected argument 'data_layout' to be a str")
        pulumi.set(__self__, "data_layout", data_layout)
        if deletion_protection and not isinstance(deletion_protection, str):
            raise TypeError("Expected argument 'deletion_protection' to be a str")
        pulumi.set(__self__, "deletion_protection", deletion_protection)
        if engine_version and not isinstance(engine_version, str):
            raise TypeError("Expected argument 'engine_version' to be a str")
        pulumi.set(__self__, "engine_version", engine_version)
        if expired_time and not isinstance(expired_time, str):
            raise TypeError("Expected argument 'expired_time' to be a str")
        pulumi.set(__self__, "expired_time", expired_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_class and not isinstance(instance_class, str):
            raise TypeError("Expected argument 'instance_class' to be a str")
        pulumi.set(__self__, "instance_class", instance_class)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_shards and not isinstance(instance_shards, list):
            raise TypeError("Expected argument 'instance_shards' to be a list")
        pulumi.set(__self__, "instance_shards", instance_shards)
        if maintenance_time and not isinstance(maintenance_time, str):
            raise TypeError("Expected argument 'maintenance_time' to be a str")
        pulumi.set(__self__, "maintenance_time", maintenance_time)
        if max_connections and not isinstance(max_connections, int):
            raise TypeError("Expected argument 'max_connections' to be a int")
        pulumi.set(__self__, "max_connections", max_connections)
        if multi_az and not isinstance(multi_az, str):
            raise TypeError("Expected argument 'multi_az' to be a str")
        pulumi.set(__self__, "multi_az", multi_az)
        if no_auth_mode and not isinstance(no_auth_mode, str):
            raise TypeError("Expected argument 'no_auth_mode' to be a str")
        pulumi.set(__self__, "no_auth_mode", no_auth_mode)
        if node_ids and not isinstance(node_ids, list):
            raise TypeError("Expected argument 'node_ids' to be a list")
        pulumi.set(__self__, "node_ids", node_ids)
        if node_number and not isinstance(node_number, int):
            raise TypeError("Expected argument 'node_number' to be a int")
        pulumi.set(__self__, "node_number", node_number)
        if parameter_group_id and not isinstance(parameter_group_id, str):
            raise TypeError("Expected argument 'parameter_group_id' to be a str")
        pulumi.set(__self__, "parameter_group_id", parameter_group_id)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if private_address and not isinstance(private_address, str):
            raise TypeError("Expected argument 'private_address' to be a str")
        pulumi.set(__self__, "private_address", private_address)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if purchase_months and not isinstance(purchase_months, int):
            raise TypeError("Expected argument 'purchase_months' to be a int")
        pulumi.set(__self__, "purchase_months", purchase_months)
        if reserve_additional_bandwidth and not isinstance(reserve_additional_bandwidth, bool):
            raise TypeError("Expected argument 'reserve_additional_bandwidth' to be a bool")
        pulumi.set(__self__, "reserve_additional_bandwidth", reserve_additional_bandwidth)
        if service_type and not isinstance(service_type, str):
            raise TypeError("Expected argument 'service_type' to be a str")
        pulumi.set(__self__, "service_type", service_type)
        if shard_capacity and not isinstance(shard_capacity, int):
            raise TypeError("Expected argument 'shard_capacity' to be a int")
        pulumi.set(__self__, "shard_capacity", shard_capacity)
        if shard_number and not isinstance(shard_number, int):
            raise TypeError("Expected argument 'shard_number' to be a int")
        pulumi.set(__self__, "shard_number", shard_number)
        if sharded_cluster and not isinstance(sharded_cluster, int):
            raise TypeError("Expected argument 'sharded_cluster' to be a int")
        pulumi.set(__self__, "sharded_cluster", sharded_cluster)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if vi_pv6 and not isinstance(vi_pv6, str):
            raise TypeError("Expected argument 'vi_pv6' to be a str")
        pulumi.set(__self__, "vi_pv6", vi_pv6)
        if vip and not isinstance(vip, str):
            raise TypeError("Expected argument 'vip' to be a str")
        pulumi.set(__self__, "vip", vip)
        if visit_addrs and not isinstance(visit_addrs, list):
            raise TypeError("Expected argument 'visit_addrs' to be a list")
        pulumi.set(__self__, "visit_addrs", visit_addrs)
        if vpc_auth_mode and not isinstance(vpc_auth_mode, str):
            raise TypeError("Expected argument 'vpc_auth_mode' to be a str")
        pulumi.set(__self__, "vpc_auth_mode", vpc_auth_mode)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_ids and not isinstance(zone_ids, list):
            raise TypeError("Expected argument 'zone_ids' to be a list")
        pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="allowListIds")
    def allow_list_ids(self) -> Sequence[builtins.str]:
        """
        白名单 ID 列表。若该参数留空，新建实例默认不加入任何白名单。您可以调用 DescribeAllowLists 接口查询当前账号下指定地域内的所有 IP 白名单信息，包括白名单 ID 信息。每个实例最多支持绑定 100 个白名单，每次可最多批量绑定 100 个白名单。每个实例最多支持绑定 1000 个 IP 地址或 CIDR 格式的 IP 地址段。
        """
        return pulumi.get(self, "allow_list_ids")

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> builtins.bool:
        """
        是否开启自动续费。取值范围如下：false（默认值）：不开启。true：开启。
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="backupPointName")
    def backup_point_name(self) -> builtins.str:
        """
        为变更前创建的全量备份设置备份名称。
        """
        return pulumi.get(self, "backup_point_name")

    @property
    @pulumi.getter
    def capacity(self) -> 'outputs.GetInstanceCapacityResult':
        """
        实例的容量信息。
        """
        return pulumi.get(self, "capacity")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        实例计费类型。取值范围如下：PrePaid：包年包月（也称预付费）。PostPaid：按量计费（也称后付费）。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="configureNodes")
    def configure_nodes(self) -> Sequence['outputs.GetInstanceConfigureNodeResult']:
        """
        设置节点所属的可用区列表。
        """
        return pulumi.get(self, "configure_nodes")

    @property
    @pulumi.getter(name="createBackup")
    def create_backup(self) -> builtins.bool:
        """
        是否在变更前创建备份。
        """
        return pulumi.get(self, "create_backup")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataLayout")
    def data_layout(self) -> builtins.str:
        """
        实例的数据存储形态。该参数仅对企业版（即ServiceType为Enterprise）实例有意义；社区版（即ServiceType为Basic）实例不涉及数据存储形态，DataLayout取值固定为RAM。若该参数留空，表示不使用数据存储形态进行筛选。
        """
        return pulumi.get(self, "data_layout")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> builtins.str:
        """
        开启或关闭实例删除保护功能。
        """
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> builtins.str:
        """
        数据库版本号。
        """
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> builtins.str:
        """
        实例到期时间。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceClass")
    def instance_class(self) -> builtins.str:
        """
        Redis 实例的类型。取值范围如下：PrimarySecondary：主备实例；Standalone：单节点实例。若该参数留空，表示不使用实例类型条件进行筛选。关于实例类型的更多信息，请参见产品架构。
        """
        return pulumi.get(self, "instance_class")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例名称。命名规则：不能以数字、中划线（-）开头；只能包含中文、字母、数字、下划线（_）和中划线（-）；长度需要在1~128个字符内。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceShards")
    def instance_shards(self) -> Sequence['outputs.GetInstanceInstanceShardResult']:
        """
        实例中所有 Shard 分片的详情列表。
        """
        return pulumi.get(self, "instance_shards")

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> builtins.str:
        """
        实例的可维护时间段，格式为HH:mm-HH:mm（UTC+8）。
        """
        return pulumi.get(self, "maintenance_time")

    @property
    @pulumi.getter(name="maxConnections")
    def max_connections(self) -> builtins.int:
        """
        实例当前单分片最大连接数。每分片的默认连接数为10000，您也可以根据业务需要调用ModifyDBInstanceMaxConn接口修改单分片的最大连接数。
        """
        return pulumi.get(self, "max_connections")

    @property
    @pulumi.getter(name="multiAz")
    def multi_az(self) -> builtins.str:
        """
        设置实例的可用区部署方案。
        """
        return pulumi.get(self, "multi_az")

    @property
    @pulumi.getter(name="noAuthMode")
    def no_auth_mode(self) -> builtins.str:
        """
        为新建实例开启或关闭免密访问功能。取值范围如下：open：开启免密访问。close（默认值）：关闭免密访问。
        """
        return pulumi.get(self, "no_auth_mode")

    @property
    @pulumi.getter(name="nodeIds")
    def node_ids(self) -> Sequence[builtins.str]:
        """
        Proxy 和 Server 节点 ID 列表。
        """
        return pulumi.get(self, "node_ids")

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> builtins.int:
        """
        每个分片中的节点数。取值范围为1~6。每个账号在每个地域下默认最多可创建4个256MiB规格的节点，若需要调整配额上限为10个，请参见账号配额。取值为1时表示创建单节点实例；取值大于1时表示创建主备实例。关于两种类型实例的功能特性差异详情，请参见功能特性差异。
        """
        return pulumi.get(self, "node_number")

    @property
    @pulumi.getter(name="parameterGroupId")
    def parameter_group_id(self) -> builtins.str:
        """
        需要应用到新实例的参数模板。缓存数据库 Redis 版为每个数据库版本都创建了一份默认的系统参数模板，模板中包含了该版本支持设置的所有参数和默认参数值。若该参数留空，默认会根据您设置的数据库版本（即 EngineVersion）为新建实例选择并应用对应版本的系统参数模板。您可以调用 DescribeParameterGroups 接口查询当前账号和地域下的所有参数模板的基本信息，包括参数模板 ID。
        """
        return pulumi.get(self, "parameter_group_id")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        设置默认数据库 default 账号的密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        自定义私网连接地址的端口号。取值范围：1024~65535。若该参数留空，私网连接地址默认使用6379端口。实例创建成功后，还可以修改私网地址的端口号，修改方法请参见修改端口号。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="privateAddress")
    def private_address(self) -> builtins.str:
        """
        实例私网连接地址的域名。
        """
        return pulumi.get(self, "private_address")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        实例所属的项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="purchaseMonths")
    def purchase_months(self) -> builtins.int:
        """
        购买时长，单位：月。取值范围如下：按月购买：1，2，3，4，5，6，7，8，9。按年购买：12，24，36。当ChargeType为PrePaid时，该参数必填。
        """
        return pulumi.get(self, "purchase_months")

    @property
    @pulumi.getter(name="reserveAdditionalBandwidth")
    def reserve_additional_bandwidth(self) -> builtins.bool:
        """
        设置是否保留额外带宽
        """
        return pulumi.get(self, "reserve_additional_bandwidth")

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> builtins.str:
        """
        实例的服务类型
        """
        return pulumi.get(self, "service_type")

    @property
    @pulumi.getter(name="shardCapacity")
    def shard_capacity(self) -> builtins.int:
        """
        实例中每个分片的内存容量。单位：MiB。
        """
        return pulumi.get(self, "shard_capacity")

    @property
    @pulumi.getter(name="shardNumber")
    def shard_number(self) -> builtins.int:
        """
        实例中的分片数量。取值范围为 2~256。仅当 ShardedCluster 取值为 1（即启用分片集群）时，需要指定该参数。
        """
        return pulumi.get(self, "shard_number")

    @property
    @pulumi.getter(name="shardedCluster")
    def sharded_cluster(self) -> builtins.int:
        """
        是否启用分片集群。取值范围如下：0：不启用。1：启用。
        """
        return pulumi.get(self, "sharded_cluster")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        实例的服务类型，取值范围如下：Basic（默认值）：社区版；Enterprise：企业版。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        设置实例的子网ID。子网具有可用区属性，必须选择目标私有网络中与实例属于同一可用区下的子网。子网是私有网络内的IP地址块私有网络中的所有云资源都必须部署在子网内，子网为云资源分配私网IP地址，您可以调用CreateSubnet接口创建子网。您可以调用DescribeSubnets接口查询指定可用区内的所有子网列表信息，包括子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        """
        设置实例的标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> builtins.str:
        """
        实例私网连接地址所对应的 IPv6 地址。仅当实例使用了 IPv6 地址时才会返回该参数。
        """
        return pulumi.get(self, "vi_pv6")

    @property
    @pulumi.getter
    def vip(self) -> builtins.str:
        """
        实例私网连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")

    @property
    @pulumi.getter(name="visitAddrs")
    def visit_addrs(self) -> Sequence['outputs.GetInstanceVisitAddrResult']:
        """
        连接地址信息。
        """
        return pulumi.get(self, "visit_addrs")

    @property
    @pulumi.getter(name="vpcAuthMode")
    def vpc_auth_mode(self) -> builtins.str:
        """
        开启或关闭免密访问功能。取值范围如下：open：开启免密访问；close：关闭免密访问。参数取值不区分大小写。
        """
        return pulumi.get(self, "vpc_auth_mode")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        设置实例的私有网络ID。建议Redis实例与需要连接的ECS实例在同一私有网络，否则它们无法通过内网互通来实现最佳性能。您可以调用CreateVpc接口创建私有网络。您可以调用DescribeVpcs接口查询符合指定条件的私有网络信息，包括私有网络ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Sequence[builtins.str]:
        """
        实例所在的可用区列表。
        """
        return pulumi.get(self, "zone_ids")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            allow_list_ids=self.allow_list_ids,
            auto_renew=self.auto_renew,
            backup_point_name=self.backup_point_name,
            capacity=self.capacity,
            charge_type=self.charge_type,
            configure_nodes=self.configure_nodes,
            create_backup=self.create_backup,
            create_time=self.create_time,
            data_layout=self.data_layout,
            deletion_protection=self.deletion_protection,
            engine_version=self.engine_version,
            expired_time=self.expired_time,
            id=self.id,
            instance_class=self.instance_class,
            instance_id=self.instance_id,
            instance_name=self.instance_name,
            instance_shards=self.instance_shards,
            maintenance_time=self.maintenance_time,
            max_connections=self.max_connections,
            multi_az=self.multi_az,
            no_auth_mode=self.no_auth_mode,
            node_ids=self.node_ids,
            node_number=self.node_number,
            parameter_group_id=self.parameter_group_id,
            password=self.password,
            port=self.port,
            private_address=self.private_address,
            project_name=self.project_name,
            purchase_months=self.purchase_months,
            reserve_additional_bandwidth=self.reserve_additional_bandwidth,
            service_type=self.service_type,
            shard_capacity=self.shard_capacity,
            shard_number=self.shard_number,
            sharded_cluster=self.sharded_cluster,
            status=self.status,
            subnet_id=self.subnet_id,
            tags=self.tags,
            vi_pv6=self.vi_pv6,
            vip=self.vip,
            visit_addrs=self.visit_addrs,
            vpc_auth_mode=self.vpc_auth_mode,
            vpc_id=self.vpc_id,
            zone_ids=self.zone_ids)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::Redis::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:redis/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        allow_list_ids=pulumi.get(__ret__, 'allow_list_ids'),
        auto_renew=pulumi.get(__ret__, 'auto_renew'),
        backup_point_name=pulumi.get(__ret__, 'backup_point_name'),
        capacity=pulumi.get(__ret__, 'capacity'),
        charge_type=pulumi.get(__ret__, 'charge_type'),
        configure_nodes=pulumi.get(__ret__, 'configure_nodes'),
        create_backup=pulumi.get(__ret__, 'create_backup'),
        create_time=pulumi.get(__ret__, 'create_time'),
        data_layout=pulumi.get(__ret__, 'data_layout'),
        deletion_protection=pulumi.get(__ret__, 'deletion_protection'),
        engine_version=pulumi.get(__ret__, 'engine_version'),
        expired_time=pulumi.get(__ret__, 'expired_time'),
        id=pulumi.get(__ret__, 'id'),
        instance_class=pulumi.get(__ret__, 'instance_class'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_shards=pulumi.get(__ret__, 'instance_shards'),
        maintenance_time=pulumi.get(__ret__, 'maintenance_time'),
        max_connections=pulumi.get(__ret__, 'max_connections'),
        multi_az=pulumi.get(__ret__, 'multi_az'),
        no_auth_mode=pulumi.get(__ret__, 'no_auth_mode'),
        node_ids=pulumi.get(__ret__, 'node_ids'),
        node_number=pulumi.get(__ret__, 'node_number'),
        parameter_group_id=pulumi.get(__ret__, 'parameter_group_id'),
        password=pulumi.get(__ret__, 'password'),
        port=pulumi.get(__ret__, 'port'),
        private_address=pulumi.get(__ret__, 'private_address'),
        project_name=pulumi.get(__ret__, 'project_name'),
        purchase_months=pulumi.get(__ret__, 'purchase_months'),
        reserve_additional_bandwidth=pulumi.get(__ret__, 'reserve_additional_bandwidth'),
        service_type=pulumi.get(__ret__, 'service_type'),
        shard_capacity=pulumi.get(__ret__, 'shard_capacity'),
        shard_number=pulumi.get(__ret__, 'shard_number'),
        sharded_cluster=pulumi.get(__ret__, 'sharded_cluster'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        vi_pv6=pulumi.get(__ret__, 'vi_pv6'),
        vip=pulumi.get(__ret__, 'vip'),
        visit_addrs=pulumi.get(__ret__, 'visit_addrs'),
        vpc_auth_mode=pulumi.get(__ret__, 'vpc_auth_mode'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_ids=pulumi.get(__ret__, 'zone_ids'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::Redis::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:redis/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        allow_list_ids=pulumi.get(__response__, 'allow_list_ids'),
        auto_renew=pulumi.get(__response__, 'auto_renew'),
        backup_point_name=pulumi.get(__response__, 'backup_point_name'),
        capacity=pulumi.get(__response__, 'capacity'),
        charge_type=pulumi.get(__response__, 'charge_type'),
        configure_nodes=pulumi.get(__response__, 'configure_nodes'),
        create_backup=pulumi.get(__response__, 'create_backup'),
        create_time=pulumi.get(__response__, 'create_time'),
        data_layout=pulumi.get(__response__, 'data_layout'),
        deletion_protection=pulumi.get(__response__, 'deletion_protection'),
        engine_version=pulumi.get(__response__, 'engine_version'),
        expired_time=pulumi.get(__response__, 'expired_time'),
        id=pulumi.get(__response__, 'id'),
        instance_class=pulumi.get(__response__, 'instance_class'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_shards=pulumi.get(__response__, 'instance_shards'),
        maintenance_time=pulumi.get(__response__, 'maintenance_time'),
        max_connections=pulumi.get(__response__, 'max_connections'),
        multi_az=pulumi.get(__response__, 'multi_az'),
        no_auth_mode=pulumi.get(__response__, 'no_auth_mode'),
        node_ids=pulumi.get(__response__, 'node_ids'),
        node_number=pulumi.get(__response__, 'node_number'),
        parameter_group_id=pulumi.get(__response__, 'parameter_group_id'),
        password=pulumi.get(__response__, 'password'),
        port=pulumi.get(__response__, 'port'),
        private_address=pulumi.get(__response__, 'private_address'),
        project_name=pulumi.get(__response__, 'project_name'),
        purchase_months=pulumi.get(__response__, 'purchase_months'),
        reserve_additional_bandwidth=pulumi.get(__response__, 'reserve_additional_bandwidth'),
        service_type=pulumi.get(__response__, 'service_type'),
        shard_capacity=pulumi.get(__response__, 'shard_capacity'),
        shard_number=pulumi.get(__response__, 'shard_number'),
        sharded_cluster=pulumi.get(__response__, 'sharded_cluster'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        vi_pv6=pulumi.get(__response__, 'vi_pv6'),
        vip=pulumi.get(__response__, 'vip'),
        visit_addrs=pulumi.get(__response__, 'visit_addrs'),
        vpc_auth_mode=pulumi.get(__response__, 'vpc_auth_mode'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_ids=pulumi.get(__response__, 'zone_ids')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DnsControlPolicyDomainListV1',
    'DnsControlPolicySource',
    'GetDnsControlPolicyDomainListV1Result',
    'GetDnsControlPolicySourceResult',
]

@pulumi.output_type
class DnsControlPolicyDomainListV1(dict):
    def __init__(__self__, *,
                 address: Optional[builtins.str] = None,
                 description: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None):
        """
        :param builtins.str address: 具体地址信息。
        :param builtins.str description: 描述信息。
        :param builtins.str type: 地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def address(self) -> Optional[builtins.str]:
        """
        具体地址信息。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class DnsControlPolicySource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "vpcId":
            suggest = "vpc_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DnsControlPolicySource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DnsControlPolicySource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DnsControlPolicySource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 region: Optional[builtins.str] = None,
                 vpc_id: Optional[builtins.str] = None):
        """
        :param builtins.str region: VPC地域信息。
        :param builtins.str vpc_id: VPC ID。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        VPC地域信息。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[builtins.str]:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class GetDnsControlPolicyDomainListV1Result(dict):
    def __init__(__self__, *,
                 address: builtins.str,
                 description: builtins.str,
                 type: builtins.str):
        """
        :param builtins.str address: 具体地址信息。
        :param builtins.str description: 描述信息。
        :param builtins.str type: 地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def address(self) -> builtins.str:
        """
        具体地址信息。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetDnsControlPolicySourceResult(dict):
    def __init__(__self__, *,
                 region: builtins.str,
                 vpc_id: builtins.str):
        """
        :param builtins.str region: VPC地域信息。
        :param builtins.str vpc_id: VPC ID。
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        VPC地域信息。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpcResult',
    'AwaitableGetVpcResult',
    'get_vpc',
    'get_vpc_output',
]

@pulumi.output_type
class GetVpcResult:
    """
    A collection of values returned by getVpc.
    """
    def __init__(__self__, account_id=None, associate_cens=None, cidr_block=None, creation_time=None, description=None, dns_servers=None, id=None, ipv4_gateway_id=None, ipv6_cidr_block=None, is_default=None, nat_gateway_ids=None, network_acl_num=None, project_name=None, route_table_ids=None, secondary_cidr_blocks=None, security_group_ids=None, status=None, subnet_ids=None, support_ipv4_gateway=None, tags=None, update_time=None, user_cidr_blocks=None, vpc_id=None, vpc_name=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if associate_cens and not isinstance(associate_cens, list):
            raise TypeError("Expected argument 'associate_cens' to be a list")
        pulumi.set(__self__, "associate_cens", associate_cens)
        if cidr_block and not isinstance(cidr_block, str):
            raise TypeError("Expected argument 'cidr_block' to be a str")
        pulumi.set(__self__, "cidr_block", cidr_block)
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dns_servers and not isinstance(dns_servers, list):
            raise TypeError("Expected argument 'dns_servers' to be a list")
        pulumi.set(__self__, "dns_servers", dns_servers)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv4_gateway_id and not isinstance(ipv4_gateway_id, str):
            raise TypeError("Expected argument 'ipv4_gateway_id' to be a str")
        pulumi.set(__self__, "ipv4_gateway_id", ipv4_gateway_id)
        if ipv6_cidr_block and not isinstance(ipv6_cidr_block, str):
            raise TypeError("Expected argument 'ipv6_cidr_block' to be a str")
        pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if nat_gateway_ids and not isinstance(nat_gateway_ids, list):
            raise TypeError("Expected argument 'nat_gateway_ids' to be a list")
        pulumi.set(__self__, "nat_gateway_ids", nat_gateway_ids)
        if network_acl_num and not isinstance(network_acl_num, str):
            raise TypeError("Expected argument 'network_acl_num' to be a str")
        pulumi.set(__self__, "network_acl_num", network_acl_num)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if route_table_ids and not isinstance(route_table_ids, list):
            raise TypeError("Expected argument 'route_table_ids' to be a list")
        pulumi.set(__self__, "route_table_ids", route_table_ids)
        if secondary_cidr_blocks and not isinstance(secondary_cidr_blocks, list):
            raise TypeError("Expected argument 'secondary_cidr_blocks' to be a list")
        pulumi.set(__self__, "secondary_cidr_blocks", secondary_cidr_blocks)
        if security_group_ids and not isinstance(security_group_ids, list):
            raise TypeError("Expected argument 'security_group_ids' to be a list")
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_ids and not isinstance(subnet_ids, list):
            raise TypeError("Expected argument 'subnet_ids' to be a list")
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if support_ipv4_gateway and not isinstance(support_ipv4_gateway, bool):
            raise TypeError("Expected argument 'support_ipv4_gateway' to be a bool")
        pulumi.set(__self__, "support_ipv4_gateway", support_ipv4_gateway)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if user_cidr_blocks and not isinstance(user_cidr_blocks, list):
            raise TypeError("Expected argument 'user_cidr_blocks' to be a list")
        pulumi.set(__self__, "user_cidr_blocks", user_cidr_blocks)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name and not isinstance(vpc_name, str):
            raise TypeError("Expected argument 'vpc_name' to be a str")
        pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        VPC所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="associateCens")
    def associate_cens(self) -> Sequence['outputs.GetVpcAssociateCenResult']:
        """
        VPC关联的CEN信息。
        """
        return pulumi.get(self, "associate_cens")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> builtins.str:
        """
        VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        创建VPC的时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> Sequence[builtins.str]:
        """
        VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        """
        return pulumi.get(self, "dns_servers")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> builtins.str:
        """
        VPC 绑定的 IPv4 网关的 ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> builtins.str:
        """
        VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> builtins.bool:
        """
        该VPC是否为默认VPC。true：默认VPC，表示该VPC是创建ECS实例时系统自动创建的VPC。false：非默认VPC，表示该VPC是用户手动创建的。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="natGatewayIds")
    def nat_gateway_ids(self) -> Sequence[builtins.str]:
        """
        VPC中创建的NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_ids")

    @property
    @pulumi.getter(name="networkAclNum")
    def network_acl_num(self) -> builtins.str:
        """
        VPC中的网络ACL的数量。
        """
        return pulumi.get(self, "network_acl_num")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        VPC所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeTableIds")
    def route_table_ids(self) -> Sequence[builtins.str]:
        """
        VPC关联的路由表ID。
        """
        return pulumi.get(self, "route_table_ids")

    @property
    @pulumi.getter(name="secondaryCidrBlocks")
    def secondary_cidr_blocks(self) -> Sequence[builtins.str]:
        """
        VPC的辅助网段。
        """
        return pulumi.get(self, "secondary_cidr_blocks")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[builtins.str]:
        """
        VPC中安全组的列表。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        VPC的状态。Creating：创建中。Pending：已创建。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Sequence[builtins.str]:
        """
        VPC中子网的列表。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="supportIpv4Gateway")
    def support_ipv4_gateway(self) -> builtins.bool:
        """
        VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        """
        return pulumi.get(self, "support_ipv4_gateway")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetVpcTagResult']:
        """
        私有网络绑定的标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        更新VPC的时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="userCidrBlocks")
    def user_cidr_blocks(self) -> Sequence[builtins.str]:
        """
        VPC的用户网段。
        """
        return pulumi.get(self, "user_cidr_blocks")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> builtins.str:
        """
        VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        return pulumi.get(self, "vpc_name")


class AwaitableGetVpcResult(GetVpcResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcResult(
            account_id=self.account_id,
            associate_cens=self.associate_cens,
            cidr_block=self.cidr_block,
            creation_time=self.creation_time,
            description=self.description,
            dns_servers=self.dns_servers,
            id=self.id,
            ipv4_gateway_id=self.ipv4_gateway_id,
            ipv6_cidr_block=self.ipv6_cidr_block,
            is_default=self.is_default,
            nat_gateway_ids=self.nat_gateway_ids,
            network_acl_num=self.network_acl_num,
            project_name=self.project_name,
            route_table_ids=self.route_table_ids,
            secondary_cidr_blocks=self.secondary_cidr_blocks,
            security_group_ids=self.security_group_ids,
            status=self.status,
            subnet_ids=self.subnet_ids,
            support_ipv4_gateway=self.support_ipv4_gateway,
            tags=self.tags,
            update_time=self.update_time,
            user_cidr_blocks=self.user_cidr_blocks,
            vpc_id=self.vpc_id,
            vpc_name=self.vpc_name)


def get_vpc(id: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcResult:
    """
    Data Source schema for Byteplus::VPC::VPC


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getVpc:getVpc', __args__, opts=opts, typ=GetVpcResult).value

    return AwaitableGetVpcResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        associate_cens=pulumi.get(__ret__, 'associate_cens'),
        cidr_block=pulumi.get(__ret__, 'cidr_block'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        description=pulumi.get(__ret__, 'description'),
        dns_servers=pulumi.get(__ret__, 'dns_servers'),
        id=pulumi.get(__ret__, 'id'),
        ipv4_gateway_id=pulumi.get(__ret__, 'ipv4_gateway_id'),
        ipv6_cidr_block=pulumi.get(__ret__, 'ipv6_cidr_block'),
        is_default=pulumi.get(__ret__, 'is_default'),
        nat_gateway_ids=pulumi.get(__ret__, 'nat_gateway_ids'),
        network_acl_num=pulumi.get(__ret__, 'network_acl_num'),
        project_name=pulumi.get(__ret__, 'project_name'),
        route_table_ids=pulumi.get(__ret__, 'route_table_ids'),
        secondary_cidr_blocks=pulumi.get(__ret__, 'secondary_cidr_blocks'),
        security_group_ids=pulumi.get(__ret__, 'security_group_ids'),
        status=pulumi.get(__ret__, 'status'),
        subnet_ids=pulumi.get(__ret__, 'subnet_ids'),
        support_ipv4_gateway=pulumi.get(__ret__, 'support_ipv4_gateway'),
        tags=pulumi.get(__ret__, 'tags'),
        update_time=pulumi.get(__ret__, 'update_time'),
        user_cidr_blocks=pulumi.get(__ret__, 'user_cidr_blocks'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vpc_name=pulumi.get(__ret__, 'vpc_name'))
def get_vpc_output(id: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpcResult]:
    """
    Data Source schema for Byteplus::VPC::VPC


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getVpc:getVpc', __args__, opts=opts, typ=GetVpcResult)
    return __ret__.apply(lambda __response__: GetVpcResult(
        account_id=pulumi.get(__response__, 'account_id'),
        associate_cens=pulumi.get(__response__, 'associate_cens'),
        cidr_block=pulumi.get(__response__, 'cidr_block'),
        creation_time=pulumi.get(__response__, 'creation_time'),
        description=pulumi.get(__response__, 'description'),
        dns_servers=pulumi.get(__response__, 'dns_servers'),
        id=pulumi.get(__response__, 'id'),
        ipv4_gateway_id=pulumi.get(__response__, 'ipv4_gateway_id'),
        ipv6_cidr_block=pulumi.get(__response__, 'ipv6_cidr_block'),
        is_default=pulumi.get(__response__, 'is_default'),
        nat_gateway_ids=pulumi.get(__response__, 'nat_gateway_ids'),
        network_acl_num=pulumi.get(__response__, 'network_acl_num'),
        project_name=pulumi.get(__response__, 'project_name'),
        route_table_ids=pulumi.get(__response__, 'route_table_ids'),
        secondary_cidr_blocks=pulumi.get(__response__, 'secondary_cidr_blocks'),
        security_group_ids=pulumi.get(__response__, 'security_group_ids'),
        status=pulumi.get(__response__, 'status'),
        subnet_ids=pulumi.get(__response__, 'subnet_ids'),
        support_ipv4_gateway=pulumi.get(__response__, 'support_ipv4_gateway'),
        tags=pulumi.get(__response__, 'tags'),
        update_time=pulumi.get(__response__, 'update_time'),
        user_cidr_blocks=pulumi.get(__response__, 'user_cidr_blocks'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vpc_name=pulumi.get(__response__, 'vpc_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DbAccountArgs', 'DbAccount']

@pulumi.input_type
class DbAccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[builtins.str],
                 account_password: pulumi.Input[builtins.str],
                 account_type: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]] = None):
        """
        The set of arguments for constructing a DbAccount resource.
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "account_password", account_password)
        pulumi.set(__self__, "account_type", account_type)
        pulumi.set(__self__, "instance_id", instance_id)
        if account_desc is not None:
            pulumi.set(__self__, "account_desc", account_desc)
        if account_privileges is not None:
            pulumi.set(__self__, "account_privileges", account_privileges)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if table_column_privileges is not None:
            pulumi.set(__self__, "table_column_privileges", table_column_privileges)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Input[builtins.str]:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @account_desc.setter
    def account_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_desc", value)

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]:
        return pulumi.get(self, "account_privileges")

    @account_privileges.setter
    def account_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]):
        pulumi.set(self, "account_privileges", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]:
        return pulumi.get(self, "table_column_privileges")

    @table_column_privileges.setter
    def table_column_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]):
        pulumi.set(self, "table_column_privileges", value)


@pulumi.input_type
class _DbAccountState:
    def __init__(__self__, *,
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]] = None,
                 account_privileges_sqls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 account_status: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 has_table_column_privilege_db_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]] = None):
        """
        Input properties used for looking up and filtering DbAccount resources.
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] account_privileges_sqls: 账号的指定数据库权限信息的 SQL 语句。
        :param pulumi.Input[builtins.str] account_status: 账号状态，取值为：Unavailable：不可用。Available：可用。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] has_table_column_privilege_db_names: 账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        if account_desc is not None:
            pulumi.set(__self__, "account_desc", account_desc)
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if account_password is not None:
            pulumi.set(__self__, "account_password", account_password)
        if account_privileges is not None:
            pulumi.set(__self__, "account_privileges", account_privileges)
        if account_privileges_sqls is not None:
            pulumi.set(__self__, "account_privileges_sqls", account_privileges_sqls)
        if account_status is not None:
            pulumi.set(__self__, "account_status", account_status)
        if account_type is not None:
            pulumi.set(__self__, "account_type", account_type)
        if has_table_column_privilege_db_names is not None:
            pulumi.set(__self__, "has_table_column_privilege_db_names", has_table_column_privilege_db_names)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if table_column_privileges is not None:
            pulumi.set(__self__, "table_column_privileges", table_column_privileges)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @account_desc.setter
    def account_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_desc", value)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]:
        return pulumi.get(self, "account_privileges")

    @account_privileges.setter
    def account_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountAccountPrivilegeArgs']]]]):
        pulumi.set(self, "account_privileges", value)

    @property
    @pulumi.getter(name="accountPrivilegesSqls")
    def account_privileges_sqls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        账号的指定数据库权限信息的 SQL 语句。
        """
        return pulumi.get(self, "account_privileges_sqls")

    @account_privileges_sqls.setter
    def account_privileges_sqls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "account_privileges_sqls", value)

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号状态，取值为：Unavailable：不可用。Available：可用。
        """
        return pulumi.get(self, "account_status")

    @account_status.setter
    def account_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_status", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="hasTableColumnPrivilegeDbNames")
    def has_table_column_privilege_db_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        """
        return pulumi.get(self, "has_table_column_privilege_db_names")

    @has_table_column_privilege_db_names.setter
    def has_table_column_privilege_db_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "has_table_column_privilege_db_names", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]:
        return pulumi.get(self, "table_column_privileges")

    @table_column_privileges.setter
    def table_column_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DbAccountTableColumnPrivilegeArgs']]]]):
        pulumi.set(self, "table_column_privileges", value)


@pulumi.type_token("bytepluscc:rdsmysql/dbAccount:DbAccount")
class DbAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountAccountPrivilegeArgs', 'DbAccountAccountPrivilegeArgsDict']]]]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountTableColumnPrivilegeArgs', 'DbAccountTableColumnPrivilegeArgsDict']]]]] = None,
                 __props__=None):
        """
        数据库账号

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/dbAccount:DbAccount example "instance_id|account_name|host"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        数据库账号

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/dbAccount:DbAccount example "instance_id|account_name|host"
        ```

        :param str resource_name: The name of the resource.
        :param DbAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_desc: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountAccountPrivilegeArgs', 'DbAccountAccountPrivilegeArgsDict']]]]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountTableColumnPrivilegeArgs', 'DbAccountTableColumnPrivilegeArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbAccountArgs.__new__(DbAccountArgs)

            __props__.__dict__["account_desc"] = account_desc
            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            if account_password is None and not opts.urn:
                raise TypeError("Missing required property 'account_password'")
            __props__.__dict__["account_password"] = account_password
            __props__.__dict__["account_privileges"] = account_privileges
            if account_type is None and not opts.urn:
                raise TypeError("Missing required property 'account_type'")
            __props__.__dict__["account_type"] = account_type
            __props__.__dict__["host"] = host
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["table_column_privileges"] = table_column_privileges
            __props__.__dict__["account_privileges_sqls"] = None
            __props__.__dict__["account_status"] = None
            __props__.__dict__["has_table_column_privilege_db_names"] = None
        super(DbAccount, __self__).__init__(
            'bytepluscc:rdsmysql/dbAccount:DbAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_desc: Optional[pulumi.Input[builtins.str]] = None,
            account_name: Optional[pulumi.Input[builtins.str]] = None,
            account_password: Optional[pulumi.Input[builtins.str]] = None,
            account_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountAccountPrivilegeArgs', 'DbAccountAccountPrivilegeArgsDict']]]]] = None,
            account_privileges_sqls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            account_status: Optional[pulumi.Input[builtins.str]] = None,
            account_type: Optional[pulumi.Input[builtins.str]] = None,
            has_table_column_privilege_db_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            host: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            table_column_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DbAccountTableColumnPrivilegeArgs', 'DbAccountTableColumnPrivilegeArgsDict']]]]] = None) -> 'DbAccount':
        """
        Get an existing DbAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_desc: 账号信息描述信息，长度不超过 256 个字符。
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] account_privileges_sqls: 账号的指定数据库权限信息的 SQL 语句。
        :param pulumi.Input[builtins.str] account_status: 账号状态，取值为：Unavailable：不可用。Available：可用。
        :param pulumi.Input[builtins.str] account_type: 账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] has_table_column_privilege_db_names: 账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        :param pulumi.Input[builtins.str] host: 指定的数据库账号可以访问数据库的 IP 地址。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbAccountState.__new__(_DbAccountState)

        __props__.__dict__["account_desc"] = account_desc
        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["account_password"] = account_password
        __props__.__dict__["account_privileges"] = account_privileges
        __props__.__dict__["account_privileges_sqls"] = account_privileges_sqls
        __props__.__dict__["account_status"] = account_status
        __props__.__dict__["account_type"] = account_type
        __props__.__dict__["has_table_column_privilege_db_names"] = has_table_column_privilege_db_names
        __props__.__dict__["host"] = host
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["table_column_privileges"] = table_column_privileges
        return DbAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> pulumi.Output[builtins.str]:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> pulumi.Output[Sequence['outputs.DbAccountAccountPrivilege']]:
        return pulumi.get(self, "account_privileges")

    @property
    @pulumi.getter(name="accountPrivilegesSqls")
    def account_privileges_sqls(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        账号的指定数据库权限信息的 SQL 语句。
        """
        return pulumi.get(self, "account_privileges_sqls")

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> pulumi.Output[builtins.str]:
        """
        账号状态，取值为：Unavailable：不可用。Available：可用。
        """
        return pulumi.get(self, "account_status")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Output[builtins.str]:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @property
    @pulumi.getter(name="hasTableColumnPrivilegeDbNames")
    def has_table_column_privilege_db_names(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        """
        return pulumi.get(self, "has_table_column_privilege_db_names")

    @property
    @pulumi.getter
    def host(self) -> pulumi.Output[builtins.str]:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> pulumi.Output[Sequence['outputs.DbAccountTableColumnPrivilege']]:
        return pulumi.get(self, "table_column_privileges")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RuleArgs', 'Rule']

@pulumi.input_type
class RuleArgs:
    def __init__(__self__, *,
                 listener_id: pulumi.Input[builtins.str],
                 action_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_config: Optional[pulumi.Input['RuleRedirectConfigArgs']] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Rule resource.
        :param pulumi.Input[builtins.str] listener_id: 监听器ID。
        :param pulumi.Input[builtins.str] action_type: 转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        :param pulumi.Input[builtins.str] description: 转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        :param pulumi.Input[builtins.str] domain: 转发规则的域名。
        :param pulumi.Input['RuleRedirectConfigArgs'] redirect_config: 重定向相关配置信息。
        :param pulumi.Input[builtins.str] server_group_id: 转发规则关联的后端服务器组的ID。
        :param pulumi.Input[builtins.str] url: 转发规则的URL。
        """
        pulumi.set(__self__, "listener_id", listener_id)
        if action_type is not None:
            pulumi.set(__self__, "action_type", action_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if redirect_config is not None:
            pulumi.set(__self__, "redirect_config", redirect_config)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Input[builtins.str]:
        """
        监听器ID。
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter(name="actionType")
    def action_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        """
        return pulumi.get(self, "action_type")

    @action_type.setter
    def action_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的域名。
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="redirectConfig")
    def redirect_config(self) -> Optional[pulumi.Input['RuleRedirectConfigArgs']]:
        """
        重定向相关配置信息。
        """
        return pulumi.get(self, "redirect_config")

    @redirect_config.setter
    def redirect_config(self, value: Optional[pulumi.Input['RuleRedirectConfigArgs']]):
        pulumi.set(self, "redirect_config", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则关联的后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的URL。
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.input_type
class _RuleState:
    def __init__(__self__, *,
                 action_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 listener_id: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_config: Optional[pulumi.Input['RuleRedirectConfigArgs']] = None,
                 rule_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Rule resources.
        :param pulumi.Input[builtins.str] action_type: 转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        :param pulumi.Input[builtins.str] description: 转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        :param pulumi.Input[builtins.str] domain: 转发规则的域名。
        :param pulumi.Input[builtins.str] listener_id: 监听器ID。
        :param pulumi.Input['RuleRedirectConfigArgs'] redirect_config: 重定向相关配置信息。
        :param pulumi.Input[builtins.str] rule_id: 转发规则ID。
        :param pulumi.Input[builtins.str] server_group_id: 转发规则关联的后端服务器组的ID。
        :param pulumi.Input[builtins.str] url: 转发规则的URL。
        """
        if action_type is not None:
            pulumi.set(__self__, "action_type", action_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if listener_id is not None:
            pulumi.set(__self__, "listener_id", listener_id)
        if redirect_config is not None:
            pulumi.set(__self__, "redirect_config", redirect_config)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="actionType")
    def action_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        """
        return pulumi.get(self, "action_type")

    @action_type.setter
    def action_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的域名。
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器ID。
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter(name="redirectConfig")
    def redirect_config(self) -> Optional[pulumi.Input['RuleRedirectConfigArgs']]:
        """
        重定向相关配置信息。
        """
        return pulumi.get(self, "redirect_config")

    @redirect_config.setter
    def redirect_config(self, value: Optional[pulumi.Input['RuleRedirectConfigArgs']]):
        pulumi.set(self, "redirect_config", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则ID。
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则关联的后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        转发规则的URL。
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("bytepluscc:clb/rule:Rule")
class Rule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 listener_id: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_config: Optional[pulumi.Input[Union['RuleRedirectConfigArgs', 'RuleRedirectConfigArgsDict']]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleTagArgs', 'RuleTagArgsDict']]]]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        转发规则用于将指定域名和URL的请求引流至指定的后端服务器组。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rule_demo = bytepluscc.clb.Rule("RuleDemo",
            listener_id="lsn-13****",
            description="RuleDemo Example",
            domain="www.***.com",
            action_type="Forward",
            server_group_id="rsp-mj***",
            url="/co3cee",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/rule:Rule example "listener_id|rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] action_type: 转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        :param pulumi.Input[builtins.str] description: 转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        :param pulumi.Input[builtins.str] domain: 转发规则的域名。
        :param pulumi.Input[builtins.str] listener_id: 监听器ID。
        :param pulumi.Input[Union['RuleRedirectConfigArgs', 'RuleRedirectConfigArgsDict']] redirect_config: 重定向相关配置信息。
        :param pulumi.Input[builtins.str] server_group_id: 转发规则关联的后端服务器组的ID。
        :param pulumi.Input[builtins.str] url: 转发规则的URL。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        转发规则用于将指定域名和URL的请求引流至指定的后端服务器组。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rule_demo = bytepluscc.clb.Rule("RuleDemo",
            listener_id="lsn-13****",
            description="RuleDemo Example",
            domain="www.***.com",
            action_type="Forward",
            server_group_id="rsp-mj***",
            url="/co3cee",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/rule:Rule example "listener_id|rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param RuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 listener_id: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_config: Optional[pulumi.Input[Union['RuleRedirectConfigArgs', 'RuleRedirectConfigArgsDict']]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleTagArgs', 'RuleTagArgsDict']]]]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleArgs.__new__(RuleArgs)

            __props__.__dict__["action_type"] = action_type
            __props__.__dict__["description"] = description
            __props__.__dict__["domain"] = domain
            if listener_id is None and not opts.urn:
                raise TypeError("Missing required property 'listener_id'")
            __props__.__dict__["listener_id"] = listener_id
            __props__.__dict__["redirect_config"] = redirect_config
            __props__.__dict__["server_group_id"] = server_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["url"] = url
            __props__.__dict__["rule_id"] = None
        super(Rule, __self__).__init__(
            'bytepluscc:clb/rule:Rule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action_type: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            listener_id: Optional[pulumi.Input[builtins.str]] = None,
            redirect_config: Optional[pulumi.Input[Union['RuleRedirectConfigArgs', 'RuleRedirectConfigArgsDict']]] = None,
            rule_id: Optional[pulumi.Input[builtins.str]] = None,
            server_group_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleTagArgs', 'RuleTagArgsDict']]]]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None) -> 'Rule':
        """
        Get an existing Rule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] action_type: 转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        :param pulumi.Input[builtins.str] description: 转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        :param pulumi.Input[builtins.str] domain: 转发规则的域名。
        :param pulumi.Input[builtins.str] listener_id: 监听器ID。
        :param pulumi.Input[Union['RuleRedirectConfigArgs', 'RuleRedirectConfigArgsDict']] redirect_config: 重定向相关配置信息。
        :param pulumi.Input[builtins.str] rule_id: 转发规则ID。
        :param pulumi.Input[builtins.str] server_group_id: 转发规则关联的后端服务器组的ID。
        :param pulumi.Input[builtins.str] url: 转发规则的URL。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleState.__new__(_RuleState)

        __props__.__dict__["action_type"] = action_type
        __props__.__dict__["description"] = description
        __props__.__dict__["domain"] = domain
        __props__.__dict__["listener_id"] = listener_id
        __props__.__dict__["redirect_config"] = redirect_config
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["server_group_id"] = server_group_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["url"] = url
        return Rule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="actionType")
    def action_type(self) -> pulumi.Output[builtins.str]:
        """
        转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        """
        return pulumi.get(self, "action_type")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        转发规则的域名。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Output[builtins.str]:
        """
        监听器ID。
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="redirectConfig")
    def redirect_config(self) -> pulumi.Output['outputs.RuleRedirectConfig']:
        """
        重定向相关配置信息。
        """
        return pulumi.get(self, "redirect_config")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[builtins.str]:
        """
        转发规则ID。
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> pulumi.Output[builtins.str]:
        """
        转发规则关联的后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.RuleTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        转发规则的URL。
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAddonResult',
    'AwaitableGetAddonResult',
    'get_addon',
    'get_addon_output',
]

@pulumi.output_type
class GetAddonResult:
    """
    A collection of values returned by getAddon.
    """
    def __init__(__self__, cluster_id=None, config=None, created_time=None, deploy_mode=None, deploy_node_type=None, id=None, name=None, status=None, updated_time=None, version=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if config and not isinstance(config, str):
            raise TypeError("Expected argument 'config' to be a str")
        pulumi.set(__self__, "config", config)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if deploy_mode and not isinstance(deploy_mode, str):
            raise TypeError("Expected argument 'deploy_mode' to be a str")
        pulumi.set(__self__, "deploy_mode", deploy_mode)
        if deploy_node_type and not isinstance(deploy_node_type, str):
            raise TypeError("Expected argument 'deploy_node_type' to be a str")
        pulumi.set(__self__, "deploy_node_type", deploy_node_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, dict):
            raise TypeError("Expected argument 'status' to be a dict")
        pulumi.set(__self__, "status", status)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        组件所在集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def config(self) -> builtins.str:
        """
        组件配置。
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        安装组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> builtins.str:
        """
        组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        """
        return pulumi.get(self, "deploy_mode")

    @property
    @pulumi.getter(name="deployNodeType")
    def deploy_node_type(self) -> builtins.str:
        """
        部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        """
        return pulumi.get(self, "deploy_node_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        组件名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> 'outputs.GetAddonStatusResult':
        """
        组件状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        组件版本。
        """
        return pulumi.get(self, "version")


class AwaitableGetAddonResult(GetAddonResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAddonResult(
            cluster_id=self.cluster_id,
            config=self.config,
            created_time=self.created_time,
            deploy_mode=self.deploy_mode,
            deploy_node_type=self.deploy_node_type,
            id=self.id,
            name=self.name,
            status=self.status,
            updated_time=self.updated_time,
            version=self.version)


def get_addon(id: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAddonResult:
    """
    Data Source schema for Byteplus::VKE::Addon


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vke/getAddon:getAddon', __args__, opts=opts, typ=GetAddonResult).value

    return AwaitableGetAddonResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        config=pulumi.get(__ret__, 'config'),
        created_time=pulumi.get(__ret__, 'created_time'),
        deploy_mode=pulumi.get(__ret__, 'deploy_mode'),
        deploy_node_type=pulumi.get(__ret__, 'deploy_node_type'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        version=pulumi.get(__ret__, 'version'))
def get_addon_output(id: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAddonResult]:
    """
    Data Source schema for Byteplus::VKE::Addon


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vke/getAddon:getAddon', __args__, opts=opts, typ=GetAddonResult)
    return __ret__.apply(lambda __response__: GetAddonResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        config=pulumi.get(__response__, 'config'),
        created_time=pulumi.get(__response__, 'created_time'),
        deploy_mode=pulumi.get(__response__, 'deploy_mode'),
        deploy_node_type=pulumi.get(__response__, 'deploy_node_type'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGatewayResult',
    'AwaitableGetGatewayResult',
    'get_gateway',
    'get_gateway_output',
]

@pulumi.output_type
class GetGatewayResult:
    """
    A collection of values returned by getGateway.
    """
    def __init__(__self__, backend_spec=None, comments=None, created_time=None, custom_log=None, events=None, gateway_id=None, id=None, log_spec=None, message=None, monitor_spec=None, name=None, network_spec=None, project_name=None, resource_spec=None, status=None, subnet_ids=None, trace_spec=None, type=None, version=None, vpc_id=None):
        if backend_spec and not isinstance(backend_spec, dict):
            raise TypeError("Expected argument 'backend_spec' to be a dict")
        pulumi.set(__self__, "backend_spec", backend_spec)
        if comments and not isinstance(comments, str):
            raise TypeError("Expected argument 'comments' to be a str")
        pulumi.set(__self__, "comments", comments)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if custom_log and not isinstance(custom_log, dict):
            raise TypeError("Expected argument 'custom_log' to be a dict")
        pulumi.set(__self__, "custom_log", custom_log)
        if events and not isinstance(events, list):
            raise TypeError("Expected argument 'events' to be a list")
        pulumi.set(__self__, "events", events)
        if gateway_id and not isinstance(gateway_id, str):
            raise TypeError("Expected argument 'gateway_id' to be a str")
        pulumi.set(__self__, "gateway_id", gateway_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if log_spec and not isinstance(log_spec, dict):
            raise TypeError("Expected argument 'log_spec' to be a dict")
        pulumi.set(__self__, "log_spec", log_spec)
        if message and not isinstance(message, str):
            raise TypeError("Expected argument 'message' to be a str")
        pulumi.set(__self__, "message", message)
        if monitor_spec and not isinstance(monitor_spec, dict):
            raise TypeError("Expected argument 'monitor_spec' to be a dict")
        pulumi.set(__self__, "monitor_spec", monitor_spec)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_spec and not isinstance(network_spec, dict):
            raise TypeError("Expected argument 'network_spec' to be a dict")
        pulumi.set(__self__, "network_spec", network_spec)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if resource_spec and not isinstance(resource_spec, dict):
            raise TypeError("Expected argument 'resource_spec' to be a dict")
        pulumi.set(__self__, "resource_spec", resource_spec)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_ids and not isinstance(subnet_ids, list):
            raise TypeError("Expected argument 'subnet_ids' to be a list")
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if trace_spec and not isinstance(trace_spec, dict):
            raise TypeError("Expected argument 'trace_spec' to be a dict")
        pulumi.set(__self__, "trace_spec", trace_spec)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="backendSpec")
    def backend_spec(self) -> 'outputs.GetGatewayBackendSpecResult':
        """
        后端服务配置信息。
        """
        return pulumi.get(self, "backend_spec")

    @property
    @pulumi.getter
    def comments(self) -> builtins.str:
        """
        网关备注信息。长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        网关创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customLog")
    def custom_log(self) -> 'outputs.GetGatewayCustomLogResult':
        """
        自定义日志配置。
        """
        return pulumi.get(self, "custom_log")

    @property
    @pulumi.getter
    def events(self) -> Sequence['outputs.GetGatewayEventResult']:
        """
        事件。
        """
        return pulumi.get(self, "events")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> builtins.str:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="logSpec")
    def log_spec(self) -> 'outputs.GetGatewayLogSpecResult':
        """
        日志配置。
        """
        return pulumi.get(self, "log_spec")

    @property
    @pulumi.getter
    def message(self) -> builtins.str:
        """
        网关创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="monitorSpec")
    def monitor_spec(self) -> 'outputs.GetGatewayMonitorSpecResult':
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitor_spec")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        网关名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkSpec")
    def network_spec(self) -> 'outputs.GetGatewayNetworkSpecResult':
        """
        网络配置信息。
        """
        return pulumi.get(self, "network_spec")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> 'outputs.GetGatewayResourceSpecResult':
        """
        资源规格配置信息。
        """
        return pulumi.get(self, "resource_spec")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        网关状态，取值：Creating：创建中。CreatedFailed：创建失败。Updating：更新中。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Sequence[builtins.str]:
        """
        子网ID列表。长度限制为1~2个。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="traceSpec")
    def trace_spec(self) -> 'outputs.GetGatewayTraceSpecResult':
        """
        链路追踪配置信息。
        """
        return pulumi.get(self, "trace_spec")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        网关版本。
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetGatewayResult(GetGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewayResult(
            backend_spec=self.backend_spec,
            comments=self.comments,
            created_time=self.created_time,
            custom_log=self.custom_log,
            events=self.events,
            gateway_id=self.gateway_id,
            id=self.id,
            log_spec=self.log_spec,
            message=self.message,
            monitor_spec=self.monitor_spec,
            name=self.name,
            network_spec=self.network_spec,
            project_name=self.project_name,
            resource_spec=self.resource_spec,
            status=self.status,
            subnet_ids=self.subnet_ids,
            trace_spec=self.trace_spec,
            type=self.type,
            version=self.version,
            vpc_id=self.vpc_id)


def get_gateway(id: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewayResult:
    """
    Data Source schema for Byteplus::APIG::Gateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:apig/getGateway:getGateway', __args__, opts=opts, typ=GetGatewayResult).value

    return AwaitableGetGatewayResult(
        backend_spec=pulumi.get(__ret__, 'backend_spec'),
        comments=pulumi.get(__ret__, 'comments'),
        created_time=pulumi.get(__ret__, 'created_time'),
        custom_log=pulumi.get(__ret__, 'custom_log'),
        events=pulumi.get(__ret__, 'events'),
        gateway_id=pulumi.get(__ret__, 'gateway_id'),
        id=pulumi.get(__ret__, 'id'),
        log_spec=pulumi.get(__ret__, 'log_spec'),
        message=pulumi.get(__ret__, 'message'),
        monitor_spec=pulumi.get(__ret__, 'monitor_spec'),
        name=pulumi.get(__ret__, 'name'),
        network_spec=pulumi.get(__ret__, 'network_spec'),
        project_name=pulumi.get(__ret__, 'project_name'),
        resource_spec=pulumi.get(__ret__, 'resource_spec'),
        status=pulumi.get(__ret__, 'status'),
        subnet_ids=pulumi.get(__ret__, 'subnet_ids'),
        trace_spec=pulumi.get(__ret__, 'trace_spec'),
        type=pulumi.get(__ret__, 'type'),
        version=pulumi.get(__ret__, 'version'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_gateway_output(id: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGatewayResult]:
    """
    Data Source schema for Byteplus::APIG::Gateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:apig/getGateway:getGateway', __args__, opts=opts, typ=GetGatewayResult)
    return __ret__.apply(lambda __response__: GetGatewayResult(
        backend_spec=pulumi.get(__response__, 'backend_spec'),
        comments=pulumi.get(__response__, 'comments'),
        created_time=pulumi.get(__response__, 'created_time'),
        custom_log=pulumi.get(__response__, 'custom_log'),
        events=pulumi.get(__response__, 'events'),
        gateway_id=pulumi.get(__response__, 'gateway_id'),
        id=pulumi.get(__response__, 'id'),
        log_spec=pulumi.get(__response__, 'log_spec'),
        message=pulumi.get(__response__, 'message'),
        monitor_spec=pulumi.get(__response__, 'monitor_spec'),
        name=pulumi.get(__response__, 'name'),
        network_spec=pulumi.get(__response__, 'network_spec'),
        project_name=pulumi.get(__response__, 'project_name'),
        resource_spec=pulumi.get(__response__, 'resource_spec'),
        status=pulumi.get(__response__, 'status'),
        subnet_ids=pulumi.get(__response__, 'subnet_ids'),
        trace_spec=pulumi.get(__response__, 'trace_spec'),
        type=pulumi.get(__response__, 'type'),
        version=pulumi.get(__response__, 'version'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .dnatentry import *
from .get_dnatentries import *
from .get_dnatentry import *
from .get_nat_ip import *
from .get_nat_ips import *
from .get_ngw import *
from .get_ngws import *
from .get_snatentries import *
from .get_snatentry import *
from .nat_ip import *
from .ngw import *
from .snatentry import *
from ._inputs import *
from . import outputs
